@@ -167,10 +167,11 @@ def _return_specific_comment_prs(all_prs, filters):
     if _validate_list_of_dict(all_prs):
         pr_issue = []
         for pull_request in all_prs:
-            issue = pull_request['issue']
-            comments = issue.get_comments()
-            logger.debug("COMMENTS: %s", [comment.body for comment in comments])
-            matched_comments = [comment.body for comment in comments if re.search(filters['comment'], comment.body)]
+            issue_comments = pull_request['issue'].get_comments()
+            review_comments = pull_request['pr'].get_review_comments()
+            comments = _return_comment_bodies(issue_comments, review_comments)
+            logger.debug("COMMENTS: %s", comments)
+            matched_comments = [comment for comment in comments if re.search(filters['comment'], comment)]
             if matched_comments:
                 pr_issue.append({'pr':pull_request['pr'], 'issue':pull_request['issue']})
         logger.debug("MATCHED COMMENTS: %s", matched_comments)
@@ -179,6 +180,21 @@ def _return_specific_comment_prs(all_prs, filters):
         return []
 
 
+def _return_comment_bodies(issue_comments, review_comments):
+    """
+    Takes paginated lists from issue comments and review comments
+    and returns a list of the comment bodies
+    """
+    comment_bodies = []
+    if issue_comments:
+        for comment in issue_comments:
+            comment_bodies.append(comment.body)
+    if review_comments:
+        for comment in review_comments:
+            comment_bodies.append(comment.body)
+    return comment_bodies
+
+
 def _check_approved_mergers(approved_users, comment_users):
     comment_approved_users = [comment_user for comment_user in comment_users if comment_user in approved_users]
     logger.debug(" APPROVED MERGERS WITH COMMENTS: %s", comment_approved_users)
